.. _api.char_range:

================
Character ranges
================
.. currentmodule:: grammatica.grammar

Constructor
-----------
.. autosummary::
   :toctree: api/

   CharRange
   CharRange.from_chars
   CharRange.from_ords

Attributes
----------

.. autosummary::
   :toctree: api/

   CharRange.char_ranges
   CharRange.negate

Rendering
---------

.. autosummary::
   :toctree: api/

   CharRange.render
   CharRange.as_string

Simplification
--------------

.. autosummary::
   :toctree: api/

   CharRange.simplify

Utility
-----------------

.. autosummary::
   :toctree: api/

   CharRange.copy
   CharRange.equals

Metadata
--------

.. warning:: ``CharRange.attrs_dict`` is considered experimental and may change without warning.

.. autosummary::
   :toctree: api/

   CharRange.attrs_dict
